@@ -733,7 +733,7 @@ class FilterProxyModel(AbstractFilterProxyModel):
             try:
                 model_column = ModelColumn(section)
                 if model_column == ModelColumn.TYPE_OR_ID:
-                    total_count = str(
+                    total_count = (
                         self.sourceModel()
                         .headerData(section, orientation, role)
                         .value()
@@ -786,3 +786,23 @@ class FilterByExtentProxyModel(AbstractFilterProxyModel):
         quality_error = cast(QualityError, tree_item_value)
 
         return quality_error.geometry.intersects(self._extent)
+
+
+class FilterByShowUserProcessedProxyModel(AbstractFilterProxyModel):
+    def __init__(self, parent: Optional[QObject] = None) -> None:
+        super().__init__(parent)
+
+        self._show_processed_errors: bool = True
+
+    def set_show_processed_errors(self, show_processed_errors: bool) -> None:
+        self._show_processed_errors = show_processed_errors
+        self.invalidateFilter()
+
+    def accept_row(
+        self, tree_item_type: QualityErrorTreeItemType, tree_item_value: Any
+    ) -> bool:
+        return not (
+            self._show_processed_errors is False
+            and tree_item_type == QualityErrorTreeItemType.ERROR
+            and cast(QualityError, tree_item_value).is_user_processed is True
+        )
